@@ -68,6 +68,8 @@ rCompare <- function(dfA,dfB,keys=NA, roundDigits = NA, mismatches = NA,trimChar
 
   # Validate arguments
   validateArguments(matchKey = keys, roundDigits = roundDigits, maxMismatch = mismatches, coerceCols =  trimChars)
+  checkNA(dfA)
+  checkNA(dfB)
   
   # Make syntactically valid names & keys
   dfA <- makeValidNames(dfA)
@@ -77,21 +79,18 @@ rCompare <- function(dfA,dfB,keys=NA, roundDigits = NA, mismatches = NA,trimChar
   # Coerce data
   coercedData <- coerceData(doa = dfA, dob = dfB)
   
+  # Warn if data is large
+  warnLargeData(as.double(nrow(coercedData[[1]])),
+                as.double(ncol(coercedData[[1]])),
+                as.double(nrow(coercedData[[2]])), 
+                as.double(ncol(coercedData[[2]])))
+  
   # Round data if needed 
   if(!is.na(roundDigits)) {
     coercedData[[1]] <- rounddf(coercedData[[1]], roundDigits)
     coercedData[[2]] <- rounddf(coercedData[[2]], roundDigits)
   }
-  
-  # Check for total number of cells
-  totalSize <- nrow(coercedData[[1]])*ncol(coercedData[[1]]) +  nrow(coercedData[[2]])*ncol(coercedData[[2]])
-  
-  # If this is too large, warn the user...
-  if(totalSize > 20E6) {
-    message(paste0("CAUTION - There are ", totalSize, " elements across both data frames.",
-           "dataCompareR may take a little longer than usual for large data sizes."))
-          }
-  
+
   # Call process flow
   outObj <- processFlow(coercedData[[1]],coercedData[[2]],roundDigits,keys,mismatches,trimChars,argsIn)
   
@@ -99,4 +98,28 @@ rCompare <- function(dfA,dfB,keys=NA, roundDigits = NA, mismatches = NA,trimChar
 
 }
 
+#' Warn users if the calculation is likely to be slow
+#' 
+#' @description Checks if there are more than 20E6 elements for comparison. If there are, spits out a warning 
+#' message that the calculation may run slowly
+#' 
+#' @param nrow_dfa number of rows in first data frame
+#' @param ncol_dfa number of columns in first data frame
+#' @param nrow_dfb number of rows in second data frame
+#' @param ncol_dfb number of columns in second data frame
+#' 
+#' @return Nothing
+warnLargeData <- function(nrow_dfa, ncol_dfa, nrow_dfb, ncol_dfb) {
+  
+  # Check for total number of cells
+  totalSize <- as.double(nrow_dfa)*as.double(ncol_dfa) + as.double(nrow_dfb)*as.double(ncol_dfb)
+  
+  # If this is too large, warn the user...
+  if(totalSize > 20E6) {
+    message(paste0("CAUTION - There are ", totalSize, " elements across both data frames.",
+                   "dataCompareR may take a little longer than usual for large data sizes."))
+  }
+  
+}
+
 
